import type { Errors, FormDataConvertible, Method, Progress, VisitOptions } from '@inertiajs/core';
import { type Writable } from 'svelte/store';
type FormDataType = Record<string, FormDataConvertible>;
type FormOptions = Omit<VisitOptions, 'data'>;
export interface InertiaFormProps<TForm extends FormDataType> {
    isDirty: boolean;
    errors: Partial<Record<keyof TForm, string>>;
    hasErrors: boolean;
    progress: Progress | null;
    wasSuccessful: boolean;
    recentlySuccessful: boolean;
    processing: boolean;
    setStore(data: TForm): void;
    setStore(key: keyof TForm, value?: FormDataConvertible): void;
    data(): TForm;
    transform(callback: (data: TForm) => object): this;
    defaults(): this;
    defaults(fields: Partial<TForm>): this;
    defaults(field?: keyof TForm, value?: FormDataConvertible): this;
    reset(...fields: (keyof TForm)[]): this;
    clearErrors(...fields: (keyof TForm)[]): this;
    setError(field: keyof TForm, value: string): this;
    setError(errors: Errors): this;
    submit(method: Method, url: string, options?: FormOptions): void;
    get(url: string, options?: FormOptions): void;
    post(url: string, options?: FormOptions): void;
    put(url: string, options?: FormOptions): void;
    patch(url: string, options?: FormOptions): void;
    delete(url: string, options?: FormOptions): void;
    cancel(): void;
}
export type InertiaForm<TForm extends FormDataType> = InertiaFormProps<TForm> & TForm;
export default function useForm<TForm extends FormDataType>(data: TForm | (() => TForm)): Writable<InertiaForm<TForm>>;
export default function useForm<TForm extends FormDataType>(rememberKey: string, data: TForm | (() => TForm)): Writable<InertiaForm<TForm>>;
export {};
